@@ -1,7 +1,10 @@
+"""
+Processing module
+"""
+
 import numpy as np
 import numpy.ma as ma
 import pandas as pd
-
 from pandas_flavor import register_dataframe_method, register_series_method
 
 
@@ -19,8 +22,19 @@ def _rolling_window(data, block):
 @register_series_method
 @register_dataframe_method
 def remove_above_water(df):
+    """Remove all data above the water line."""
+    return remove_up_to(df, idx=0)
+
+
+@register_series_method
+@register_dataframe_method
+def remove_up_to(df, idx):
+    """
+    Remove all the data above a certain index value where index can be pressure or depth.
+
+    """
     new_df = df.copy()
-    return new_df[new_df.index >= 0]
+    return new_df[new_df.index >= idx]
 
 
 @register_series_method
@@ -99,6 +113,7 @@ def press_check(df):
 
 
 def _bindata(series, delta, method):
+    """Average the data into bins of the size `delta`."""
     start = np.ceil(series.index[0])
     stop = np.floor(series.index[-1])
     new_index = np.arange(start, stop, delta)
@@ -111,7 +126,7 @@ def _bindata(series, delta, method):
         return pd.Series(data, index=new_index, name=series.name)
     else:
         raise ValueError(
-            f"Expected method `average` or `interpolate`, but got {method}."
+            f"Expected method `average` or `interpolate`, but got {method}.",
         )
     return new_series
 
@@ -160,7 +175,7 @@ def _despike(series, n1, n2, block, keep):
     mean = np.r_[mean, np.tile(mean[-1], block - 1)]
     values = series.values.astype(float)
     mask = np.abs(values - mean.filled(fill_value=np.NaN)) > std.filled(
-        fill_value=np.NaN
+        fill_value=np.NaN,
     )
 
     clean = series.astype(float).copy()
@@ -201,7 +216,7 @@ def _smooth(series, window_len, window):
     if window not in list(windows.keys()):
         raise ValueError(
             """window must be one of 'flat', 'hanning',
-                         'hamming', 'bartlett', 'blackman'"""
+                         'hamming', 'bartlett', 'blackman'""",
         )
 
     s = np.r_[
@@ -229,6 +244,7 @@ def smooth(df, window_len=11, window="hanning"):
 
 
 def _movingaverage(series, window_size=48):
+    """Moving average function on a pandas series."""
     window = np.ones(int(window_size)) / float(window_size)
     return pd.Series(np.convolve(series, window, "same"), index=series.index)
 
@@ -236,6 +252,14 @@ def _movingaverage(series, window_size=48):
 @register_series_method
 @register_dataframe_method
 def movingaverage(df, window_size=48):
+    """
+    Moving average on a data frame or series.
+
+    Inputs:
+      windows_size : integer
+
+    """
+
     if isinstance(df, pd.Series):
         new_df = _movingaverage(df, window_size=window_size)
     else:
